/**
  TMR1 Generated Driver File
  @Company    Microchip Technology Inc.
  @File Name    tmr1.c
  @Summary    This is the generated driver implementation file for the TMR1 driver using MPLAB(c) Code Configurator
  @Description
    This source file provides APIs for TMR1.
    Generation Information :
        Product Revision  :  MPLAB(c) Code Configurator - 3.16
        Device            :  PIC16F1829
        Driver Version    :  2.00
    The generated drivers are tested against the following:
        Compiler          :  XC8 1.35
        MPLAB             :  MPLAB X 3.20
*/

/*************** Includes *****************************************************************************************/
#include <xc.h>
#include "tmr1.h"

/*************** Global Data Declarations *************************************************************************/
volatile uint16_t timer1ReloadVal;

/*******************************************************************************************************************
  Section: TMR1 APIs
*******************************************************************************************************************/
void TMR1_Initialize(void)
{
    //Set the Timer to the options selected in the GUI
    //T1CKPS 1:8; T1OSCEN disabled; nT1SYNC do_not_synchronize; TMR1CS FOSC/4; TMR1ON off; 
    T1CON = 0x34;
    //T1GSS T1G; TMR1GE disabled; T1GTM disabled; T1GPOL low; T1GGO done; T1GSPM disabled; 
    T1GCON = 0x00;
    //TMR1H 60; 
    TMR1H = 0x3C;
    //TMR1L 176; 
    TMR1L = 0xB0;
    // Load the TMR value to reload variable
    timer1ReloadVal=(TMR1H << 8) | TMR1L;
    // Clearing IF flag before enabling the interrupt.
    PIR1bits.TMR1IF = 0;
    // Enabling TMR1 interrupt.
    PIE1bits.TMR1IE = 1;
    // Set Default Interrupt Handler
    TMR1_SetInterruptHandler(TMR1_DefaultInterruptHandler);
}

void TMR1_StartTimer(void)
{
    // Start the Timer by writing to TMRxON bit
    T1CONbits.TMR1ON = 1;
}

void TMR1_StopTimer(void)
{
    // Stop the Timer by writing to TMRxON bit
    T1CONbits.TMR1ON = 0;
}

void TMR1_ISR(void)
{
    static volatile unsigned int CountCallBack = 0;
    // Clear the TMR1 interrupt flag
    PIR1bits.TMR1IF = 0;
    TMR1H = (timer1ReloadVal >> 8);
    TMR1L = timer1ReloadVal;
    // callback function - called every 10th pass
    if (++CountCallBack >= TMR1_INTERRUPT_TICKER_FACTOR)
    {
        // ticker function call
        TMR1_CallBack();
        // reset ticker counter
        CountCallBack = 0;
    }
}

void TMR1_CallBack(void)
{
    // Add your custom callback code here
    if(TMR1_InterruptHandler)
    {
        TMR1_InterruptHandler();
    }
}

void TMR1_SetInterruptHandler(void* InterruptHandler){
    TMR1_InterruptHandler = InterruptHandler;
}

void TMR1_DefaultInterruptHandler(void){
    // add your TMR1 interrupt custom code
    // or set custom function using TMR1_SetInterruptHandler()
}
/*************** End of File **************************************************************************************/